@@ -276,9 +276,7 @@ public class TextFileBufferManager implements ITextFileBufferManager {
 					if (type != null)
 						return type.isKindOf(TEXT_CONTENT_TYPE);
 				}
-			} catch (CoreException ex) {
-				// ignore: API specification tells return true if content type can't be determined
-			} catch (IOException ex) {
+			} catch (CoreException | IOException ex) {
 				// ignore: API specification tells return true if content type can't be determined
 			}
 
@@ -465,13 +463,13 @@ public class TextFileBufferManager implements ITextFileBufferManager {
 						if (document.getDocumentPartitioner() != null) {
 							String message= NLSUtility.format(FileBuffersMessages.TextFileBufferManager_warning_documentSetupInstallsDefaultPartitioner, participant.getClass());
 							IStatus status= new Status(IStatus.WARNING, FileBuffersPlugin.PLUGIN_ID, IStatus.OK, message, null);
-							FileBuffersPlugin.getDefault().getLog().log(status);
+							Platform.getLog(ResourceTextFileBufferManager.class).log(status);
 						}
 					}
 					@Override
 					public void handleException(Throwable t) {
 						IStatus status= new Status(IStatus.ERROR, FileBuffersPlugin.PLUGIN_ID, IStatus.OK, FileBuffersMessages.TextFileBufferManager_error_documentSetupFailed, t);
-						FileBuffersPlugin.getDefault().getLog().log(status);
+						Platform.getLog(ResourceTextFileBufferManager.class).log(status);
 					}
 				};
 				SafeRunner.run(runnable);
@@ -504,7 +502,7 @@ public class TextFileBufferManager implements ITextFileBufferManager {
 					@Override
 					public void handleException(Throwable t) {
 						IStatus status= new Status(IStatus.ERROR, FileBuffersPlugin.PLUGIN_ID, IStatus.OK, FileBuffersMessages.TextFileBufferManager_error_documentFactoryFailed, t);
-						FileBuffersPlugin.getDefault().getLog().log(status);
+						Platform.getLog(ResourceTextFileBufferManager.class).log(status);
 					}
 				};
 				SafeRunner.run(runnable);
@@ -805,7 +803,7 @@ public class TextFileBufferManager implements ITextFileBufferManager {
 	 * @since 3.3
 	 */
 	protected String getLineDelimiterPreference(IPath location, LocationKind locationKind) {
-		return System.getProperty("line.separator"); //$NON-NLS-1$
+		return System.lineSeparator();
 	}
 
 }
