@@ -108,7 +108,7 @@ public abstract class DisplayHelper {
 	/**
 	 * The condition which has to be met in order for {@link #waitForCondition(Display, long)} to
 	 * return before the timeout elapses.
-	 * 
+	 *
 	 * @return <code>true</code> if the condition is met, <code>false</code> if the event loop
 	 *         should be driven some more
 	 */
@@ -532,8 +532,6 @@ final class DisplayWaiter {
 	 * Implements state consistency checking.
 	 *
 	 * @param states the allowed states
-	 * @throws junit.framework.AssertionFailedError if the current state is not
-	 *         in <code>states</code>
 	 */
 	private void assertStates(int states) {
 		Assert.assertTrue("illegal state", isState(states));
@@ -558,7 +556,7 @@ final class DisplayWaiter {
 	 * @return a string representation of the states
 	 */
 	private String name(int states) {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		boolean comma= false;
 		if ((states & RUNNING) == RUNNING) {
 			buf.append("RUNNING");
