@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -609,7 +609,7 @@ abstract public class AbstractHoverInformationControlManager extends AbstractInf
 	private MouseTracker fMouseTracker= new MouseTracker();
 	/**
 	 * The remembered hover event.
-     * @since 3.0
+	 * @since 3.0
 	 */
 	private MouseEvent fHoverEvent= null;
 	/** The remembered hover event state mask of the keyboard modifiers */
@@ -845,7 +845,7 @@ abstract public class AbstractHoverInformationControlManager extends AbstractInf
 		fReplacingDelayJob= new Job("AbstractHoverInformationControlManager Replace Delayer") { //$NON-NLS-1$
 			@Override
 			public IStatus run(final IProgressMonitor monitor) {
-		        if (monitor.isCanceled() || display.isDisposed()) {
+				if (monitor.isCanceled() || display.isDisposed()) {
 					return Status.CANCEL_STATUS;
 				}
 				display.syncExec(() -> {
@@ -939,14 +939,14 @@ abstract public class AbstractHoverInformationControlManager extends AbstractInf
 		return fHoverEvent;
 	}
 
- 	/**
+	/**
 	 * Returns the SWT event state of the most recent mouse hover event.
 	 *
 	 * @return the SWT event state of the most recent mouse hover event
 	 */
 	protected int getHoverEventStateMask() {
 		return fHoverEventStateMask;
- 	}
+	}
 
 	/**
 	 * Returns an adapter that gives access to internal methods.
@@ -985,9 +985,7 @@ abstract public class AbstractHoverInformationControlManager extends AbstractInf
 		super.install(subjectControl);
 	}
 
-	/**
-	 * {@inheritDoc}
-	 */
+	@Override
 	public void install(Control subjectControl) {
 		install(subjectControl, subjectControl);
 	}
