@@ -18,10 +18,13 @@
  *******************************************************************************/
 package org.eclipse.jface.text.contentassist;
 
+import static org.eclipse.jface.util.Util.isValid;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.eclipse.osgi.util.TextProcessor;
 
@@ -30,8 +33,6 @@ import org.eclipse.swt.custom.BusyIndicator;
 import org.eclipse.swt.custom.StyleRange;
 import org.eclipse.swt.events.ControlEvent;
 import org.eclipse.swt.events.ControlListener;
-import org.eclipse.swt.events.DisposeEvent;
-import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.FocusListener;
 import org.eclipse.swt.events.KeyAdapter;
@@ -41,7 +42,6 @@ import org.eclipse.swt.events.MouseAdapter;
 import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
-import org.eclipse.swt.events.TraverseEvent;
 import org.eclipse.swt.events.TraverseListener;
 import org.eclipse.swt.events.VerifyEvent;
 import org.eclipse.swt.graphics.Color;
@@ -57,6 +57,7 @@ import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Listener;
+import org.eclipse.swt.widgets.Monitor;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableItem;
@@ -81,6 +82,7 @@ import org.eclipse.jface.preference.JFacePreferences;
 import org.eclipse.jface.resource.JFaceColors;
 import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.util.Geometry;
+import org.eclipse.jface.util.Util;
 import org.eclipse.jface.viewers.StyledString;
 
 import org.eclipse.jface.text.AbstractInformationControlManager;
@@ -139,6 +141,9 @@ class CompletionProposalPopup implements IContentAssistListener {
 
 		@Override
 		public Object execute(ExecutionEvent event) throws ExecutionException {
+			if (fProposalTable.isDisposed()) {
+				return null;
+			}
 			int itemCount= fProposalTable.getItemCount();
 			int selectionIndex= fProposalTable.getSelectionIndex();
 			switch (fOperationCode) {
@@ -223,7 +228,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	final class ProposalSelectionListener implements KeyListener {
 		@Override
 		public void keyPressed(KeyEvent e) {
-			if (!Helper.okToUse(fProposalShell))
+			if (!isValid(fProposalShell))
 				return;
 
 			if (e.character == 0 && e.keyCode == SWT.CTRL) {
@@ -236,7 +241,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 
 		@Override
 		public void keyReleased(KeyEvent e) {
-			if (!Helper.okToUse(fProposalShell))
+			if (!isValid(fProposalShell))
 				return;
 
 			if (e.character == 0 && e.keyCode == SWT.CTRL) {
@@ -257,7 +262,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 
 		@Override
 		public void keyPressed(KeyEvent e) {
-			if (!Helper.okToUse(fProposalShell))
+			if (!isValid(fProposalShell))
 				return;
 
 			int accelerator= SWTKeySupport.convertEventToUnmodifiedAccelerator(e);
@@ -345,12 +350,10 @@ class CompletionProposalPopup implements IContentAssistListener {
 	private final Runnable fFilterRunnable= new Runnable() {
 		@Override
 		public void run() {
-			if (!fIsFilterPending)
+			if (!fIsFilterPending.compareAndSet(true, false))
 				return;
 
-			fIsFilterPending= false;
-
-			if (!Helper.okToUse(fContentAssistSubjectControlAdapter.getControl()))
+			if (!isValid(fContentAssistSubjectControlAdapter.getControl()))
 				return;
 
 			int offset= fContentAssistSubjectControlAdapter.getSelectedRange().x;
@@ -362,12 +365,11 @@ class CompletionProposalPopup implements IContentAssistListener {
 					proposals= computeFilteredProposals(offset, event);
 				}
 			} catch (BadLocationException x) {
-			} finally {
 				fDocumentEvents.clear();
 			}
 			fFilterOffset= offset;
 
-			if (proposals != null && proposals.size() > 0)
+			if (proposals != null && !proposals.isEmpty())
 				setProposals(proposals, fIsFilteredSubset);
 			else {
 				hide();
@@ -390,7 +392,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 *
 	 * @since 3.1.1
 	 */
-	private boolean fIsFilterPending= false;
+	private final AtomicBoolean fIsFilterPending= new AtomicBoolean(false);
 	/**
 	 * The info message at the bottom of the popup, or <code>null</code> for no popup (if
 	 * ContentAssistant does not provide one).
@@ -490,7 +492,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 
 		final Control control= fContentAssistSubjectControlAdapter.getControl();
 
-		if (!Helper.okToUse(fProposalShell) && control != null && !control.isDisposed()) {
+		if (!isValid(fProposalShell) && control != null && !control.isDisposed()) {
 			// add the listener before computing the proposals so we don't move the caret
 			// when the user types fast.
 			fContentAssistSubjectControlAdapter.addKeyListener(fKeyListener);
@@ -596,7 +598,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 * Creates the proposal selector.
 	 */
 	void createProposalSelector() {
-		if (Helper.okToUse(fProposalShell))
+		if (isValid(fProposalShell))
 			return;
 
 		Control control= fContentAssistSubjectControlAdapter.getControl();
@@ -604,12 +606,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 		fProposalShell.setFont(JFaceResources.getDefaultFont());
 		fProposalTable= new Table(fProposalShell, SWT.H_SCROLL | SWT.V_SCROLL | SWT.VIRTUAL);
 
-		Listener listener= new Listener() {
-			@Override
-			public void handleEvent(Event event) {
-				handleSetData(event);
-			}
-		};
+		Listener listener= this::handleSetData;
 		fProposalTable.addListener(SWT.SetData, listener);
 
 		fIsColoredLabelsSupportEnabled= fContentAssistant.isColoredLabelsSupportEnabled();
@@ -638,9 +635,16 @@ class CompletionProposalPopup implements IContentAssistListener {
 			fProposalShell.setSize(size);
 		} else {
 			int height= fProposalTable.getItemHeight() * 10;
-			// use golden ratio as default aspect ratio
-			final double aspectRatio= (1 + Math.sqrt(5)) / 2;
+			// use 2 x ratio as default aspect ratio instead of (1 + Math.sqrt(5)) / 2
+			double aspectRatio= 2;
 			int width= (int) (height * aspectRatio);
+
+			// Make sure our bounds still fit to the screen
+			Monitor monitor= Util.getClosestMonitor(fProposalShell.getDisplay(), getLocation());
+			Rectangle bounds= monitor.getClientArea();
+			width= Math.min(width, bounds.width / 4);
+			height= Math.min(height, bounds.height / 4);
+
 			Rectangle trim= fProposalTable.computeTrim(0, 0, width, height);
 			data.heightHint= trim.height;
 			data.widthHint= trim.width;
@@ -674,7 +678,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 
 		Color foreground= getForegroundColor(control);
 		if (foreground == null) {
-			foreground= JFaceColors.getInformationViewerBackgroundColor(Display.getDefault());
+			foreground= JFaceColors.getInformationViewerForegroundColor(Display.getDefault());
 		}
 
 		fProposalShell.setBackground(background);
@@ -694,12 +698,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 
 		fPopupCloser.install(fContentAssistant, fProposalTable, fAdditionalInfoController);
 
-		fProposalShell.addDisposeListener(new DisposeListener() {
-			@Override
-			public void widgetDisposed(DisposeEvent e) {
-				unregister(); // but don't dispose the shell, since we're being called from its disposal event!
-			}
-		});
+		fProposalShell.addDisposeListener(event -> unregister());
 
 		fProposalTable.setHeaderVisible(false);
 
@@ -715,12 +714,12 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 */
 	int getMinimalHeight() {
 		int height= 0;
-		if (Helper.okToUse(fProposalTable)) {
+		if (isValid(fProposalTable)) {
 			int items= fProposalTable.getItemHeight() * 10;
 			Rectangle trim= fProposalTable.computeTrim(0, 0, SWT.DEFAULT, items);
 			height= trim.height;
 		}
-		if (Helper.okToUse(fMessageText))
+		if (isValid(fMessageText))
 			height+= fMessageText.getSize().y + 1;
 		return height;
 	}
@@ -731,62 +730,59 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 * @param control the control to watch for focus
 	 * @since 3.2
 	 */
-    private void addCommandSupport(final Control control) {
-    	final KeySequence commandSequence= fContentAssistant.getRepeatedInvocationKeySequence();
-    	if (commandSequence != null && !commandSequence.isEmpty() && fContentAssistant.isRepeatedInvocationMode()) {
-    		control.addFocusListener(new FocusListener() {
-    			private CommandKeyListener fCommandKeyListener;
-    			@Override
+	private void addCommandSupport(final Control control) {
+		final KeySequence commandSequence= fContentAssistant.getRepeatedInvocationKeySequence();
+		if (commandSequence != null && !commandSequence.isEmpty() && fContentAssistant.isRepeatedInvocationMode()) {
+			control.addFocusListener(new FocusListener() {
+				private CommandKeyListener fCommandKeyListener;
+				@Override
 				public void focusGained(FocusEvent e) {
-    				if (Helper.okToUse(control)) {
-    					if (fCommandKeyListener == null) {
-    						fCommandKeyListener= new CommandKeyListener(commandSequence);
-    						fProposalTable.addKeyListener(fCommandKeyListener);
-    					}
-    				}
-    			}
-    			@Override
+					if (isValid(control)) {
+						if (fCommandKeyListener == null) {
+							fCommandKeyListener= new CommandKeyListener(commandSequence);
+							fProposalTable.addKeyListener(fCommandKeyListener);
+						}
+					}
+				}
+				@Override
 				public void focusLost(FocusEvent e) {
-    				if (fCommandKeyListener != null) {
-    					control.removeKeyListener(fCommandKeyListener);
-    					fCommandKeyListener= null;
-    				}
-    			}
-    		});
-    	}
-    	if (fAdditionalInfoController != null) {
-	    	control.addFocusListener(new FocusListener() {
-	    		private TraverseListener fTraverseListener;
-	    		@Override
+					if (fCommandKeyListener != null) {
+						control.removeKeyListener(fCommandKeyListener);
+						fCommandKeyListener= null;
+					}
+				}
+			});
+		}
+		if (fAdditionalInfoController != null) {
+			control.addFocusListener(new FocusListener() {
+				private TraverseListener fTraverseListener;
+				@Override
 				public void focusGained(FocusEvent e) {
-	    			if (Helper.okToUse(control)) {
-	    				if (fTraverseListener == null) {
-							fTraverseListener= new TraverseListener() {
-								@Override
-								public void keyTraversed(TraverseEvent event) {
-									if (event.detail == SWT.TRAVERSE_TAB_NEXT) {
-										IInformationControl iControl= fAdditionalInfoController.getCurrentInformationControl2();
-										if (fAdditionalInfoController.getInternalAccessor().canReplace(iControl)) {
-											fAdditionalInfoController.getInternalAccessor().replaceInformationControl(true);
-											event.doit= false;
-										}
+					if (isValid(control)) {
+						if (fTraverseListener == null) {
+							fTraverseListener= event -> {
+								if (event.detail == SWT.TRAVERSE_TAB_NEXT) {
+									IInformationControl iControl= fAdditionalInfoController.getCurrentInformationControl2();
+									if (fAdditionalInfoController.getInternalAccessor().canReplace(iControl)) {
+										fAdditionalInfoController.getInternalAccessor().replaceInformationControl(true);
+										event.doit= false;
 									}
 								}
 							};
-	    					fProposalTable.addTraverseListener(fTraverseListener);
-	    				}
-	    			}
-	    		}
-	    		@Override
+							fProposalTable.addTraverseListener(fTraverseListener);
+						}
+					}
+				}
+				@Override
 				public void focusLost(FocusEvent e) {
-	    			if (fTraverseListener != null) {
-	    				control.removeTraverseListener(fTraverseListener);
-	    				fTraverseListener= null;
-	    			}
-	    		}
-	    	});
-    	}
-    }
+					if (fTraverseListener != null) {
+						control.removeTraverseListener(fTraverseListener);
+						fTraverseListener= null;
+					}
+				}
+			});
+		}
+	}
 
 	/**
 	 * Returns the background color to use.
@@ -871,7 +867,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 			StyleRange[] styleRanges= null;
 			Image image= null;
 			try {
-				if (fIsColoredLabelsSupportEnabled && current instanceof ICompletionProposalExtension7 && Helper.okToUse(fProposalShell)) {
+				if (fIsColoredLabelsSupportEnabled && current instanceof ICompletionProposalExtension7 && isValid(fProposalShell)) {
 					BoldStylerProvider boldStylerProvider= fContentAssistant.getBoldStylerProvider();
 					if (boldStylerProvider == null) {
 						boldStylerProvider= new BoldStylerProvider(fProposalShell.getFont());
@@ -924,11 +920,11 @@ class CompletionProposalPopup implements IContentAssistListener {
 		/* Make sure that there is no filter runnable pending.
 		 * See https://bugs.eclipse.org/bugs/show_bug.cgi?id=31427
 		 */
-		if (fIsFilterPending)
+		if (fIsFilterPending.get())
 			fFilterRunnable.run();
 
 		// filter runnable may have hidden the proposals
-		if (!Helper.okToUse(fProposalTable))
+		if (!isValid(fProposalTable))
 			return null;
 
 		int i= fProposalTable.getSelectionIndex();
@@ -1049,7 +1045,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 * @return <code>true</code> if the popup has the focus
 	 */
 	public boolean hasFocus() {
-		if (Helper.okToUse(fProposalShell)) {
+		if (isValid(fProposalShell)) {
 			if ((fProposalShell.getDisplay().getActiveShell() == fProposalShell))
 				return true;
 			/*
@@ -1086,7 +1082,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 			registry.unregister(fFocusHelper);
 		}
 
-		if (Helper.okToUse(fProposalShell)) {
+		if (isValid(fProposalShell)) {
 
 			fContentAssistant.removeContentAssistListener(this, ContentAssistant.PROPOSAL_SELECTOR);
 
@@ -1169,7 +1165,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 		if (oldProposals != fFilteredProposals) // reentrant call was first - abort
 			return;
 
-		if (Helper.okToUse(fProposalTable)) {
+		if (isValid(fProposalTable)) {
 			if (oldProposal instanceof ICompletionProposalExtension2 && fViewer != null)
 				((ICompletionProposalExtension2) oldProposal).unselected(fViewer);
 
@@ -1226,7 +1222,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 */
 	void displayProposals() {
 
-		if (!Helper.okToUse(fProposalShell) ||  !Helper.okToUse(fProposalTable))
+		if (!isValid(fProposalShell) || !isValid(fProposalTable))
 			return;
 
 		if (fContentAssistant.addContentAssistListener(this, ContentAssistant.PROPOSAL_SELECTOR)) {
@@ -1263,10 +1259,10 @@ class CompletionProposalPopup implements IContentAssistListener {
 			 */
 			fProposalShell.setVisible(true); // may run event loop on GTK
 			// transfer focus since no verify key listener can be attached
-			if (!fContentAssistSubjectControlAdapter.supportsVerifyKeyListener() && Helper.okToUse(fProposalShell))
+			if (!fContentAssistSubjectControlAdapter.supportsVerifyKeyListener() && isValid(fProposalShell))
 				fProposalShell.setFocus(); // may run event loop on GTK ??
 
-			if (fAdditionalInfoController != null && Helper.okToUse(fProposalTable)) {
+			if (fAdditionalInfoController != null && isValid(fProposalTable)) {
 				fAdditionalInfoController.install(fProposalTable);
 				fAdditionalInfoController.handleTableSelectionChanged();
 			}
@@ -1302,7 +1298,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 
 	@Override
 	public boolean verifyKey(VerifyEvent e) {
-		if (!Helper.okToUse(fProposalShell))
+		if (!isValid(fProposalShell))
 			return true;
 
 		char key= e.character;
@@ -1482,8 +1478,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 * offset of the original invocation of the content assistant.
 	 */
 	void filterProposals() {
-		if (!fIsFilterPending) {
-			fIsFilterPending= true;
+		if (fIsFilterPending.compareAndSet(false, true)) {
 			Control control= fContentAssistSubjectControlAdapter.getControl();
 			control.getDisplay().asyncExec(fFilterRunnable);
 		}
@@ -1499,6 +1494,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 * @since 3.0
 	 */
 	List<ICompletionProposal> computeFilteredProposals(int offset, DocumentEvent event) {
+		fDocumentEvents.clear();
 
 		if (offset == fInvocationOffset && event == null) {
 			fIsFilteredSubset= false;
@@ -1569,7 +1565,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 * @since 3.0
 	 */
 	public void setFocus() {
-		if (Helper.okToUse(fProposalShell)) {
+		if (isValid(fProposalShell)) {
 			fProposalShell.setFocus();
 		}
 	}
@@ -1602,7 +1598,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 	 * @since 3.0
 	 */
 	public String incrementalComplete() {
-		if (Helper.okToUse(fProposalShell) && fFilteredProposals != null) {
+		if (isValid(fProposalShell) && fFilteredProposals != null) {
 			if (fLastCompletionOffset == fFilterOffset) {
 				handleRepeatedInvocation();
 			} else {
@@ -1615,7 +1611,7 @@ class CompletionProposalPopup implements IContentAssistListener {
 			if (fKeyListener == null)
 				fKeyListener= new ProposalSelectionListener();
 
-			if (!Helper.okToUse(fProposalShell) && !control.isDisposed())
+			if (!isValid(fProposalShell) && !control.isDisposed())
 				fContentAssistSubjectControlAdapter.addKeyListener(fKeyListener);
 
 			BusyIndicator.showWhile(control.getDisplay(), () -> {
