@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -18,7 +18,6 @@
  *******************************************************************************/
 package org.eclipse.jface.text.source;
 
-import java.lang.ref.WeakReference;
 import java.util.Arrays;
 import java.util.function.Consumer;
 
@@ -32,12 +31,9 @@ import org.eclipse.swt.events.MouseMoveListener;
 import org.eclipse.swt.events.MouseWheelListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Font;
-import org.eclipse.swt.graphics.FontData;
 import org.eclipse.swt.graphics.FontMetrics;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
-import org.eclipse.swt.graphics.ImageData;
-import org.eclipse.swt.graphics.ImageDataProvider;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.widgets.Canvas;
@@ -46,8 +42,6 @@ import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.TypedListener;
 
-import org.eclipse.jface.util.Util;
-
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.IRegion;
@@ -67,17 +61,6 @@ import org.eclipse.jface.text.TextEvent;
  */
 public class LineNumberRulerColumn implements IVerticalRulerColumn {
 
-	/**
-	 * <code>true</code> if we're on a Mac, where drawing on an Image currently only draws at 100% zoom level,
-	 * which results in blurry line numbers on a Retina display.
-	 *
-	 * @see <a href="https://bugs.eclipse.org/516293">bug 516293</a>
-	 * @since 3.6
-	 */
-	private final boolean IS_MAC_BUG_516293= Util.isMac()
-			&& !"false".equals(System.getProperty("LineNumberRulerColumn.retina.workaround")) //$NON-NLS-1$ //$NON-NLS-2$
-			&& internalSupportsZoomedPaint();
-
 	/**
 	 * Internal listener class.
 	 */
@@ -398,6 +381,16 @@ public class LineNumberRulerColumn implements IVerticalRulerColumn {
 	private int fCachedNumberOfDigits= -1;
 	/** Flag indicating whether a relayout is required */
 	private boolean fRelayoutRequired= false;
+	/** Last top pixel. */
+	private int fLastTopPixel = -1;
+	/** Last top model line. */
+	private int fLastTopModelLine;
+	/** Last number of lines visible. */
+	private int fLastNumberOfLines;
+	/** Last bottom model line. */
+	private int fLastBottomModelLine;
+	/** Last canvas height used. */
+	private int fLastHeight= -1;
 	/**
 	 * Redraw runnable lock
 	 * @since 3.0
@@ -420,20 +413,13 @@ public class LineNumberRulerColumn implements IVerticalRulerColumn {
 	};
 	/* @since 3.2 */
 	private MouseHandler fMouseHandler;
-	/*
-	 * Zoom level and cached font for the current painting operation. Workaround for bug 516293.
-	 * @since 3.12
-	 */
-	int fZoom= 100;
-	private WeakReference<Font> fLastFont;
-	private Font fLastZoomedFont;
 
 	/**
 	 * Redraw the ruler handler called when a line height change.
 	 *
 	 * @since 3.13
 	 */
-	private Consumer<StyledText> lineHeightChangeHandler= (t) -> postRedraw();
+	private Consumer<StyledText> lineHeightChangeHandler= t -> postRedraw();
 
 	/**
 	 * Constructs a new vertical ruler column.
@@ -644,15 +630,11 @@ public class LineNumberRulerColumn implements IVerticalRulerColumn {
 		fCanvas.addMouseMoveListener(fMouseHandler);
 		fCanvas.addMouseWheelListener(fMouseHandler);
 
-		if (fCachedTextViewer != null) {
-			VisibleLinesTracker.track(fCachedTextViewer, lineHeightChangeHandler);
-			fCachedTextViewer.addTextListener(fInternalListener);
+		fCachedTextViewer.addTextListener(fInternalListener);
 
-
-			if (fFont == null) {
-				if (fCachedTextWidget != null && !fCachedTextWidget.isDisposed())
-					fFont= fCachedTextWidget.getFont();
-			}
+		if (fFont == null) {
+			if (!fCachedTextWidget.isDisposed())
+				fFont= fCachedTextWidget.getFont();
 		}
 
 		if (fFont != null)
@@ -676,12 +658,6 @@ public class LineNumberRulerColumn implements IVerticalRulerColumn {
 			fBuffer.dispose();
 			fBuffer= null;
 		}
-
-		if (fLastZoomedFont != null) {
-			fLastZoomedFont.dispose();
-			fLastZoomedFont= null;
-			fLastFont= null;
-		}
 	}
 
 	/**
@@ -693,115 +669,128 @@ public class LineNumberRulerColumn implements IVerticalRulerColumn {
 
 		Point size= fCanvas.getSize();
 
-		if (size.x <= 0 || size.y <= 0)
+		if (size.x <= 0 || size.y <= 0) {
 			return;
+		}
 
 		if (fBuffer != null) {
 			Rectangle r= fBuffer.getBounds();
-			if (IS_MAC_BUG_516293 || r.width != size.x || r.height != size.y) {
+			if (r.width != size.x || r.height != size.y) {
 				fBuffer.dispose();
 				fBuffer= null;
 			}
 		}
 
 		ILineRange visibleLines= JFaceTextUtil.getVisibleModelLines(fCachedTextViewer);
-		if (visibleLines == null)
+		if (visibleLines == null) {
 			return;
-
-		if (IS_MAC_BUG_516293) {
-			/* FIXME: Workaround (bug 516293):
-			 * Relies on SWT implementation detail that GC drawing on macOS only draws at 100% zoom level.
-			 * For higher zoom levels (200%), we manually scale the font and drawing coordinates,
-			 * and then use getImageData(100) to extract the high-resolution image data. */
-			fBuffer= new Image(fCanvas.getDisplay(), (ImageDataProvider) zoom -> {
-				fZoom = zoom;
-				internalSetZoom(zoom);
-				int width= size.x * zoom / 100;
-				int height= size.y * zoom / 100;
-				Image gcImage= new Image(fCanvas.getDisplay(), width, height);
-
-				GC gc= new GC(gcImage);
-				Font font= fCanvas.getFont();
-				if (zoom != 100) {
-					if (fLastFont != null && font == fLastFont.get()) {
-						font= fLastZoomedFont;
-					} else {
-						fLastFont= new WeakReference<>(font);
-						FontData fontData= font.getFontData()[0];
-						fontData.setHeight(fontData.getHeight() * zoom / 100);
-						font= new Font(font.getDevice(), fontData);
-						fLastZoomedFont= font;
-					}
-				}
-				gc.setFont(font);
-				if (fForeground != null)
-					gc.setForeground(fForeground);
-
-				try {
-					gc.setBackground(getBackground(fCanvas.getDisplay()));
-					gc.fillRectangle(0, 0, width, height);
-
-					doPaint(gc, visibleLines);
-				} finally {
-					gc.dispose();
-					fZoom= 100;
-				}
-
-				ImageData imageData= gcImage.getImageData(100);
-				gcImage.dispose();
-				return imageData;
-			});
-
-		} else {
-			if (fBuffer == null)
-				fBuffer= new Image(fCanvas.getDisplay(), size.x, size.y);
-
-			GC gc= new GC(fBuffer);
-			gc.setFont(fCanvas.getFont());
-			if (fForeground != null)
-				gc.setForeground(fForeground);
-
-			try {
-				gc.setBackground(getBackground(fCanvas.getDisplay()));
-				gc.fillRectangle(0, 0, size.x, size.y);
-
-				doPaint(gc, visibleLines);
-			} finally {
-				gc.dispose();
-			}
 		}
 
+		boolean bufferStillValid = fBuffer != null;
+		if (fBuffer == null) {
+			fBuffer= new Image(fCanvas.getDisplay(), size.x, size.y);
+		}
+		GC bufferGC= new GC(fBuffer);
+		Image newBuffer= null;
+		try {
+			int topPixel= fCachedTextWidget.getTopPixel();
+			int bufferY= 0;
+			int bufferH= size.y;
+			int numberOfLines= visibleLines.getNumberOfLines();
+			int dy= topPixel - fLastTopPixel;
+			int topModelLine= visibleLines.getStartLine();
+			int bottomModelLine= topModelLine + numberOfLines - 1;
+			int bottomWidgetLine= JFaceTextUtil.modelLineToWidgetLine(fCachedTextViewer, bottomModelLine);
+			boolean atEnd= bottomWidgetLine + 1 >= fCachedTextWidget.getLineCount();
+			int height= size.y;
+			if (dy != 0 && !atEnd && bufferStillValid && fLastTopPixel >= 0 && numberOfLines > 1 && numberOfLines == fLastNumberOfLines) {
+				int bottomPixel= fCachedTextWidget.getLinePixel(bottomWidgetLine + 1);
+				if (dy > 0 && bottomPixel < size.y) {
+					// Can occur on GTK with static scrollbars; see bug 551320.
+					height= bottomPixel;
+				}
+				if (dy > 0 && dy < height) {
+					int goodPixels= height;
+					if (goodPixels > fLastHeight) {
+						// Dont copy empty pixels from last time.
+						goodPixels= fLastHeight;
+					}
+					if (dy < goodPixels) {
+						bufferGC.copyArea(0, dy, size.x, goodPixels - dy, 0, 0);
+						bufferY= goodPixels - dy;
+						bufferH= height - bufferY;
+					} else {
+						// Redraw everything.
+						height= size.y;
+						dy= 0;
+					}
+				} else if (dy < 0 && -dy < height) {
+					bufferGC.copyArea(0, 0, size.x, height + dy, 0, -dy);
+					bufferY= 0;
+					bufferH= -dy;
+				} else {
+					height= size.y;
+					dy= 0;
+				}
+			} else {
+				dy= 0;
+			}
+			// dy == 0 means now "draw everything", either because there was no overlap, or we indeed didn't move
+			// (refresh or other cases), or there was a resize, or it's the first time, or we are showing the very
+			// last line.
+			if (dy != 0) {
+				// Reduce the line range.
+				if (dy > 0) {
+					visibleLines= new LineRange(fLastBottomModelLine, bottomModelLine - fLastBottomModelLine + 1);
+				} else {
+					visibleLines= new LineRange(topModelLine, fLastTopModelLine - topModelLine + 1);
+				}
+			}
+			fLastTopPixel= topPixel;
+			fLastTopModelLine= topModelLine;
+			fLastNumberOfLines= numberOfLines;
+			fLastBottomModelLine= bottomModelLine;
+			fLastHeight= height;
+			if (dy != 0) {
+				// Some rulers may paint outside the line region. Let them paint in a new image,
+				// the copy the wanted bits.
+				newBuffer= new Image(fCanvas.getDisplay(), size.x, size.y);
+				GC localGC= new GC(newBuffer);
+				try {
+					initializeGC(localGC, 0, bufferY, size.x, bufferH);
+					doPaint(localGC, visibleLines);
+				} finally {
+					localGC.dispose();
+				}
+				bufferGC.drawImage(newBuffer, 0, bufferY, size.x, bufferH, 0, bufferY, size.x, bufferH);
+				if (dy > 0 && bufferY + bufferH < size.y) {
+					// Scrolled down in the text, but didn't use the full height of the Canvas: clear
+					// the rest. Occurs on GTK with static scrollbars; the area cleared here is the
+					// bit next to the horizontal scrollbar. See bug 551320.
+					bufferGC.setBackground(getBackground(fCanvas.getDisplay()));
+					bufferGC.fillRectangle(0, bufferY + bufferH, size.x, size.y - bufferY - bufferH + 1);
+				}
+			} else {
+				// We redraw everything; paint directly into the buffer
+				initializeGC(bufferGC, 0, 0, size.x, size.y);
+				doPaint(bufferGC, visibleLines);
+			}
+		} finally {
+			bufferGC.dispose();
+			if (newBuffer != null) {
+				newBuffer.dispose();
+			}
+		}
 		dest.drawImage(fBuffer, 0, 0);
 	}
 
-	/**
-	 * This method is not API and it is expected to disappear in Eclipse 4.8.
-	 * Subclasses that want to take advantage of the unsupported workaround for bug 516258
-	 * can re-implement this method and return true.
-	 *
-	 * @return true iff this class supports the workaround for bug 516258
-	 *
-	 * @nooverride This method is not intended to be re-implemented or extended by clients.
-	 * @noreference This method is not intended to be referenced by clients.
-	 * @since 3.12
-	 */
-	protected boolean internalSupportsZoomedPaint() {
-		return getClass().getPackage().equals(LineNumberChangeRulerColumn.class.getPackage());
-	}
-
-	/**
-	 * This method is not API and it is expected to disappear in Eclipse 4.8.
-	 * Subclasses that want to take advantage of the unsupported workaround for bug 516258
-	 * can override this method and store the given zoom level for later use.
-	 *
-	 * @param zoom the zoom level to use for drawing operations
-	 *
-	 * @nooverride This method is not intended to be re-implemented or extended by clients.
-	 * @noreference This method is not intended to be referenced by clients.
-	 * @since 3.12
-	 */
-	protected void internalSetZoom(int zoom) {
-		// callback for subclasses
+	private void initializeGC(GC gc, int x, int y, int width, int height) {
+		gc.setFont(fCanvas.getFont());
+		if (fForeground != null) {
+			gc.setForeground(fForeground);
+		}
+		gc.setBackground(getBackground(fCanvas.getDisplay()));
+		gc.fillRectangle(x, y, width, height);
 	}
 
 	/**
@@ -838,8 +827,8 @@ public class LineNumberRulerColumn implements IVerticalRulerColumn {
 	void doPaint(GC gc, ILineRange visibleLines) {
 		Display display= fCachedTextWidget.getDisplay();
 
-		// draw diff info
-		int y= -JFaceTextUtil.getHiddenTopLinePixels(fCachedTextWidget);
+		int firstWidgetLineToDraw= JFaceTextUtil.modelLineToWidgetLine(fCachedTextViewer, visibleLines.getStartLine());
+		int y= fCachedTextWidget.getLinePixel(firstWidgetLineToDraw);
 
 		// add empty lines if line is wrapped
 		boolean isWrapActive= fCachedTextWidget.getWordWrap();
@@ -942,7 +931,7 @@ public class LineNumberRulerColumn implements IVerticalRulerColumn {
 		int indentation= fIndentation[index];
 		int baselineBias= getBaselineBias(gc, widgetLine);
 		int verticalIndent= fCachedTextViewer.getTextWidget().getLineVerticalIndent(widgetLine);
-		gc.drawString(s, indentation * fZoom / 100, (y + baselineBias + verticalIndent) * fZoom / 100, true);
+		gc.drawString(s, indentation, y + baselineBias + verticalIndent, true);
 	}
 
 	/**
