@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -128,7 +128,7 @@ public class FileSearchPage extends AbstractTextSearchViewPage implements IAdapt
 	private SortAction fSortByPathAction;
 
 
-	private static final String[] SHOW_IN_TARGETS= new String[] { IPageLayout.ID_RES_NAV };
+	private static final String[] SHOW_IN_TARGETS = new String[] { IPageLayout.ID_PROJECT_EXPLORER };
 	private  static final IShowInTargetList SHOW_IN_TARGET_LIST= () -> SHOW_IN_TARGETS;
 
 	public FileSearchPage() {
@@ -270,7 +270,7 @@ public class FileSearchPage extends AbstractTextSearchViewPage implements IAdapt
 		fActionGroup.setContext(new ActionContext(getSite().getSelectionProvider().getSelection()));
 		fActionGroup.fillContextMenu(mgr);
 		FileSearchQuery query= (FileSearchQuery) getInput().getQuery();
-		if (query.getSearchString().length() > 0) {
+		if (!query.getSearchString().isEmpty()) {
 			IStructuredSelection selection = getViewer().getStructuredSelection();
 			if (!selection.isEmpty()) {
 				ReplaceAction replaceSelection= new ReplaceAction(getSite().getShell(), (FileSearchResult)getInput(), selection.toArray());
