@@ -14,6 +14,7 @@
 package org.eclipse.search.internal.ui.text;
 
 import java.net.URI;
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -26,8 +27,6 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
-import com.ibm.icu.text.Collator;
-
 import org.eclipse.core.filesystem.URIUtil;
 
 import org.eclipse.core.runtime.Assert;
@@ -206,7 +205,7 @@ public class ReplaceRefactoring extends Refactoring {
 	@Override
 	public RefactoringStatus checkInitialConditions(IProgressMonitor pm) throws CoreException, OperationCanceledException {
 		String searchString= getQuery().getSearchString();
-		if (searchString.length() == 0) {
+		if (searchString.isEmpty()) {
 			return RefactoringStatus.createFatalErrorStatus(SearchMessages.ReplaceRefactoring_error_illegal_search_string);
 		}
 		fMatches.clear();
@@ -260,7 +259,7 @@ public class ReplaceRefactoring extends Refactoring {
 	}
 
 	public int getNumberOfFiles() {
-		return fMatches.keySet().size();
+		return fMatches.size();
 	}
 
 	public int getNumberOfMatches() {
