@@ -260,7 +260,7 @@ class AnnotationsConfigurationBlock implements IPreferenceConfigurationBlock {
 
 
 		fDecorationViewer= new ComboViewer(optionsComposite, SWT.READ_ONLY);
-		fDecorationViewer.setContentProvider(new ArrayContentProvider());
+		fDecorationViewer.setContentProvider(ArrayContentProvider.getInstance());
 		fDecorationViewer.setLabelProvider(new ArrayLabelProvider());
 		fDecorationViewer.setComparator(new ViewerComparator(Collator.getInstance()));
 
