@@ -13,14 +13,13 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.editors.text;
 
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
 import java.util.StringTokenizer;
 
-import com.ibm.icu.text.Collator;
-
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.KeyEvent;
 import org.eclipse.swt.events.KeyListener;
@@ -178,9 +177,9 @@ class HyperlinkDetectorsConfigurationBlock implements IPreferenceConfigurationBl
 	private OverlayPreferenceStore.OverlayKey[] createOverlayStoreKeys() {
 		ArrayList<OverlayKey> overlayKeys= new ArrayList<>();
 
-		for (int i= 0; i < fHyperlinkDetectorDescriptors.length; i++) {
-			overlayKeys.add(new OverlayPreferenceStore.OverlayKey(OverlayPreferenceStore.STRING, fHyperlinkDetectorDescriptors[i].getId()));
-			overlayKeys.add(new OverlayPreferenceStore.OverlayKey(OverlayPreferenceStore.INT, fHyperlinkDetectorDescriptors[i].getId() + HyperlinkDetectorDescriptor.STATE_MASK_POSTFIX));
+		for (HyperlinkDetectorDescriptor fHyperlinkDetectorDescriptor : fHyperlinkDetectorDescriptors) {
+			overlayKeys.add(new OverlayPreferenceStore.OverlayKey(OverlayPreferenceStore.STRING, fHyperlinkDetectorDescriptor.getId()));
+			overlayKeys.add(new OverlayPreferenceStore.OverlayKey(OverlayPreferenceStore.INT, fHyperlinkDetectorDescriptor.getId() + HyperlinkDetectorDescriptor.STATE_MASK_POSTFIX));
 		}
 
 		overlayKeys.add(new OverlayPreferenceStore.OverlayKey(OverlayPreferenceStore.STRING, AbstractDecoratedTextEditorPreferenceConstants.EDITOR_HYPERLINK_KEY_MODIFIER));
@@ -432,9 +431,11 @@ class HyperlinkDetectorsConfigurationBlock implements IPreferenceConfigurationBl
 
 	private Object[] getCheckedItems() {
 		List<ListItem> result= new ArrayList<>();
-		for (int i= 0; i < fListModel.length; i++)
-			if (!fStore.getBoolean(fListModel[i].id))
-				result.add(fListModel[i]);
+		for (ListItem i : fListModel) {
+			if (!fStore.getBoolean(i.id)) {
+				result.add(i);
+			}
+		}
 		return result.toArray();
 	}
 
@@ -498,8 +499,7 @@ class HyperlinkDetectorsConfigurationBlock implements IPreferenceConfigurationBl
 
 	private ListItem[] createListModel() {
 		ArrayList<ListItem> listModelItems= new ArrayList<>();
-		for (int i= 0; i < fHyperlinkDetectorDescriptors.length; i++) {
-			HyperlinkDetectorDescriptor desc= fHyperlinkDetectorDescriptors[i];
+		for (HyperlinkDetectorDescriptor desc : fHyperlinkDetectorDescriptors) {
 			HyperlinkDetectorTargetDescriptor target= desc.getTarget();
 
 			int stateMask= fStore.getInt(desc.getId() + HyperlinkDetectorDescriptor.STATE_MASK_POSTFIX);
@@ -589,7 +589,7 @@ class HyperlinkDetectorsConfigurationBlock implements IPreferenceConfigurationBl
 		if (modifiers == null)
 			return -1;
 
-		if (modifiers.length() == 0)
+		if (modifiers.isEmpty())
 			return SWT.NONE;
 
 		int stateMask= 0;
@@ -662,7 +662,7 @@ class HyperlinkDetectorsConfigurationBlock implements IPreferenceConfigurationBl
 		if (modifierString == null)
 			modifierString= ""; //$NON-NLS-1$
 		String newModifierString= Action.findModifierString(modifier);
-		if (modifierString.length() == 0)
+		if (modifierString.isEmpty())
 			return newModifierString;
 		return NLSUtility.format(TextEditorMessages.HyperlinkKeyModifier_concatModifierStrings, new String[] {modifierString, newModifierString});
 	}
@@ -688,7 +688,7 @@ class HyperlinkDetectorsConfigurationBlock implements IPreferenceConfigurationBl
 				fPreferencePage.setErrorMessage(null);
 				break;
 			default:
-				if (message.length() == 0) {
+				if (message.isEmpty()) {
 					message= null;
 				}
 				fPreferencePage.setMessage(null);
