@@ -13,13 +13,12 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.editors.text;
 
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import com.ibm.icu.text.Collator;
-
 import org.osgi.service.prefs.BackingStoreException;
 
 import org.eclipse.swt.SWT;
@@ -205,13 +204,13 @@ class LinkedModeConfigurationBlock implements IPreferenceConfigurationBlock {
 
 	private List<String[]> getStyles(Object type) {
 		if (type.equals(MASTER))
-			return Arrays.asList(new String[][] {BOX, DASHED_BOX, HIGHLIGHT, UNDERLINE, SQUIGGLES});
+			return Arrays.asList(BOX, DASHED_BOX, HIGHLIGHT, UNDERLINE, SQUIGGLES);
 		if (type.equals(SLAVE))
-			return Arrays.asList(new String[][] {BOX, DASHED_BOX, HIGHLIGHT, UNDERLINE, SQUIGGLES});
+			return Arrays.asList(BOX, DASHED_BOX, HIGHLIGHT, UNDERLINE, SQUIGGLES);
 		if (type.equals(TARGET))
-			return Arrays.asList(new String[][] {BOX, DASHED_BOX, HIGHLIGHT, UNDERLINE, SQUIGGLES});
+			return Arrays.asList(BOX, DASHED_BOX, HIGHLIGHT, UNDERLINE, SQUIGGLES);
 		if (type.equals(EXIT))
-			return Arrays.asList(new String[][] {IBEAM});
+			return Arrays.asList(new String[][] { IBEAM });
 		return new ArrayList<>();
 	}
 
@@ -273,7 +272,7 @@ class LinkedModeConfigurationBlock implements IPreferenceConfigurationBlock {
 		fShowInTextCheckBox.setLayoutData(gd);
 
 		fDecorationViewer= new ComboViewer(optionsComposite, SWT.READ_ONLY);
-		fDecorationViewer.setContentProvider(new ArrayContentProvider());
+		fDecorationViewer.setContentProvider(ArrayContentProvider.getInstance());
 		fDecorationViewer.setLabelProvider(new ArrayLabelProvider());
 		fDecorationViewer.setComparator(new ViewerComparator(Collator.getInstance()));
 
@@ -466,8 +465,7 @@ class LinkedModeConfigurationBlock implements IPreferenceConfigurationBlock {
 			// set selection
 			if (selection == null) {
 				String val= getPreferenceStore().getString(item.textStyleKey);
-				for (Iterator<String[]> iter= list.iterator(); iter.hasNext();) {
-					String[] elem= iter.next();
+				for (String[] elem : list) {
 					if (elem[1].equals(val)) {
 						selection= elem;
 						break;
@@ -527,8 +525,8 @@ class LinkedModeConfigurationBlock implements IPreferenceConfigurationBlock {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				boolean state= master.getSelection();
-				for (int i= 0; i < slaves.length; i++) {
-					slaves[i].setEnabled(state);
+				for (Control slave : slaves) {
+					slave.setEnabled(state);
 				}
 			}
 
