@@ -15,13 +15,12 @@
 package org.eclipse.ui.texteditor.templates;
 
 import java.io.IOException;
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import com.ibm.icu.text.Collator;
-
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CLabel;
 import org.eclipse.swt.custom.SashForm;
@@ -272,7 +271,7 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 			if ((object1 instanceof TemplateContextType)
 					&& (object2 instanceof TemplateContextType)) {
 				return Collator.getInstance().compare(((TemplateContextType) object1).getName(),
-						((TemplateContextType) object1).getName());
+						((TemplateContextType) object2).getName());
 			}
 			return super.compare(viewer, object1, object2);
 		}
@@ -347,9 +346,10 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 		private TemplatePersistenceData[] getTemplates(String contextId) {
 			List<TemplatePersistenceData> templateList= new ArrayList<>();
 			TemplatePersistenceData[] datas= getTemplateStore().getTemplateData(false);
-			for (int i= 0; i < datas.length; i++) {
-				if (datas[i].isEnabled() && datas[i].getTemplate().getContextTypeId().equals(contextId))
-					templateList.add(datas[i]);
+			for (TemplatePersistenceData data : datas) {
+				if (data.isEnabled() && data.getTemplate().getContextTypeId().equals(contextId)) {
+					templateList.add(data);
+				}
 			}
 			return templateList
 					.toArray(new TemplatePersistenceData[templateList.size()]);
@@ -376,9 +376,10 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 				if (datas.length <= 0)
 					return false;
 
-				for (int i= 0; i < datas.length; i++) {
-					if (datas[i].isEnabled() && datas[i].getTemplate().getContextTypeId().equals(contextId))
+				for (TemplatePersistenceData data : datas) {
+					if (data.isEnabled() && data.getTemplate().getContextTypeId().equals(contextId)) {
 						return true;
+					}
 				}
 				return false;
 			}
@@ -500,7 +501,7 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 
 		int sashSize= fPreferenceStore.getInt(SASH_SIZE_PREF_ID);
 		fControl.setWeights(new int[] { sashSize, 100 - sashSize });
-		fTemplateChangeListener = event -> getShell().getDisplay().asyncExec(() -> refresh());
+		fTemplateChangeListener = event -> getShell().getDisplay().asyncExec(this::refresh);
 		getTemplatePreferenceStore().addPropertyChangeListener(fTemplateChangeListener);
 		updateContextTypes(getEditorContextTypeIds());
 	}
@@ -552,13 +553,18 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 
 	/**
 	 * Creates and opens a dialog to edit the given template.
-	 * <p
-	 * Subclasses may override this method to provide a custom dialog.</p>
+	 * <p>
+	 * Subclasses may override this method to provide a custom dialog.
+	 * </p>
 	 *
-	 * @param template the template being edited
-	 * @param edit <code>true</code> if the dialog allows editing
-	 * @param isNameModifiable <code>true</code> if the template name may be modified
-	 * @return the created or modified template, or <code>null</code> if the editing failed
+	 * @param template
+	 *            the template being edited
+	 * @param edit
+	 *            <code>true</code> if the dialog allows editing
+	 * @param isNameModifiable
+	 *            <code>true</code> if the template name may be modified
+	 * @return the created or modified template, or <code>null</code> if the
+	 *         editing failed
 	 */
 	protected Template editTemplate(Template template, boolean edit, boolean isNameModifiable) {
 		EditTemplateDialog dialog= new EditTemplateDialog(getShell(), template, edit, isNameModifiable, getContextTypeRegistry());
@@ -1104,7 +1110,7 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 	private void hookContextMenu() {
 		MenuManager menuMgr= new MenuManager(POPUP_MENU_ID);
 		menuMgr.setRemoveAllWhenShown(true);
-		menuMgr.addMenuListener(manager -> fillContextMenu(manager));
+		menuMgr.addMenuListener(this::fillContextMenu);
 		fContextMenu= menuMgr.createContextMenu(fTreeViewer.getControl());
 		fTreeViewer.getControl().setMenu(fContextMenu);
 		getSite().registerContextMenu(POPUP_MENU_ID, menuMgr, fTreeViewer);
@@ -1322,9 +1328,9 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 	 *
 	 */
 	private void moveTemplates(TemplatePersistenceData[] templates, String contextId) {
-		for (int i= 0; i < templates.length; i++) {
-			Template t= templates[i].getTemplate();
-			templates[i].setTemplate(new Template(t.getName(), t.getDescription(), contextId, t
+		for (TemplatePersistenceData template : templates) {
+			Template t = template.getTemplate();
+			template.setTemplate(new Template(t.getName(), t.getDescription(), contextId, t
 					.getPattern(), t.isAutoInsertable()));
 		}
 		saveTemplateStore();
@@ -1369,8 +1375,8 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 					new Object[] { Integer.valueOf(selectedTemplates.length) });
 		if (!MessageDialog.openQuestion(getShell(), title, message))
 			return;
-		for (int i= 0; i < selectedTemplates.length; i++) {
-			getTemplateStore().delete(selectedTemplates[i]);
+		for (TemplatePersistenceData selectedTemplate : selectedTemplates) {
+			getTemplateStore().delete(selectedTemplate);
 		}
 		saveTemplateStore();
 		fTreeViewer.setSelection(new StructuredSelection(new Object[] {}), true);
@@ -1494,9 +1500,8 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 	 */
 	private void storeCollapseState() {
 		TreeItem[] items= fTreeViewer.getTree().getItems();
-		for (int i= 0; i < items.length; i++) {
-			fPreferenceStore.setValue(CONTEXT_COLLAPSE_PREF_ID
-					+ ((TemplateContextType) items[i].getData()).getId(), !items[i].getExpanded());
+		for (TreeItem item : items) {
+			fPreferenceStore.setValue(CONTEXT_COLLAPSE_PREF_ID + ((TemplateContextType) item.getData()).getId(), !item.getExpanded());
 		}
 	}
 
@@ -1509,13 +1514,13 @@ public abstract class AbstractTemplatesPage extends Page implements ITemplatesPa
 		try {
 			fTreeViewer.refresh();
 			TreeItem[] items= fTreeViewer.getTree().getItems();
-			for (int i= 0; i < items.length; i++) {
-				boolean isExpanded= !fPreferenceStore.getBoolean(CONTEXT_COLLAPSE_PREF_ID
-						+ ((TemplateContextType) items[i].getData()).getId());
-				if (isExpanded)
-					fTreeViewer.expandToLevel(items[i].getData(), AbstractTreeViewer.ALL_LEVELS);
-				else
-					fTreeViewer.collapseToLevel(items[i].getData(), AbstractTreeViewer.ALL_LEVELS);
+			for (TreeItem item : items) {
+				boolean isExpanded = !fPreferenceStore.getBoolean(CONTEXT_COLLAPSE_PREF_ID + ((TemplateContextType) item.getData()).getId());
+				if (isExpanded) {
+					fTreeViewer.expandToLevel(item.getData(), AbstractTreeViewer.ALL_LEVELS);
+				} else {
+					fTreeViewer.collapseToLevel(item.getData(), AbstractTreeViewer.ALL_LEVELS);
+				}
 			}
 		} finally {
 			fTreeViewer.getTree().setRedraw(true);
