@@ -16,8 +16,8 @@ package org.eclipse.ui.texteditor.templates;
 
 import org.eclipse.swt.widgets.Composite;
 
+import org.eclipse.core.runtime.Adapters;
 import org.eclipse.core.runtime.Assert;
-import org.eclipse.core.runtime.Platform;
 
 import org.eclipse.jface.text.templates.persistence.TemplatePersistenceData;
 import org.eclipse.jface.text.templates.persistence.TemplateStore;
@@ -26,6 +26,7 @@ import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.part.IContributedContentsView;
 import org.eclipse.ui.part.IPage;
 import org.eclipse.ui.part.MessagePage;
 import org.eclipse.ui.part.PageBook;
@@ -132,7 +133,7 @@ public final class TemplatesView extends PageBookView {
 		// Try to get template page.
 		ITemplatesPage page= part.getAdapter(ITemplatesPage.class);
 		if (page == null)
-			page= Platform.getAdapterManager().getAdapter(part, ITemplatesPage.class);
+			page = Adapters.adapt(part, ITemplatesPage.class);
 		if (page == null)
 			return null; // There is no template page
 
@@ -167,6 +168,14 @@ public final class TemplatesView extends PageBookView {
 		partActivated(part);
 	}
 
+	@Override
+	public <T> T getAdapter(Class<T> key) {
+		if (key == IContributedContentsView.class) {
+			return key.cast((IContributedContentsView) this::getCurrentContributingPart);
+		}
+		return super.getAdapter(key);
+	}
+
 	/**
 	 * Returns the template store of the current page.
 	 *
